#
# spec file for package sapnwbootstrap-formula
#
# Copyright (c) 2019 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


# See also http://en.opensuse.org/openSUSE:Specfile_guidelines

Name:           sapnwbootstrap-formula
Version:        0.6.6+git.1625824616.eb6e12c
Release:        1.9
Summary:        SAP Netweaver platform deployment formula
License:        Apache-2.0

Url:            https://github.com/SUSE/%{name}
Source0:        %{name}-%{version}.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch
Requires:       habootstrap-formula
Requires:       salt-shaptools
%if 0%{?suse_version} < 1500
Recommends:     salt-formulas-configuration
%else
Requires:       salt-formulas-configuration
%endif

%define fname netweaver
%define fdir  %{_datadir}/salt-formulas
%define ftemplates templates

%description
SAP Netweaver deployment salt formula. This formula is capable to install
SAP Netweaver instances (ASCS, ERS, PAS, AAS) and perform some basic actions to optimize
their usage.

In order to use the formula, salt must be available in the system. The package comes automatically
in SLE15. To use it in SLE12, salt (and it sub-components) comes from the Advanced systems management
module, which can be added running the `SUSEConnect -p sle-module-adv-systems-management/12/{{ arch }}`

%prep
%setup -q

%build

%install

mkdir -p %{buildroot}%{fdir}/states/%{fname}
mkdir -p %{buildroot}%{fdir}/metadata/%{fname}
cp -R %{fname} %{buildroot}%{fdir}/states
cp -R %{ftemplates} %{buildroot}%{fdir}/states/%{fname}
cp pillar.example %{buildroot}%{fdir}/states/%{fname}
cp -R form.yml %{buildroot}%{fdir}/metadata/%{fname}
if [ -f metadata.yml ]
then
  cp -R metadata.yml %{buildroot}%{fdir}/metadata/%{fname}
fi


%files
%defattr(-,root,root,-)
%if 0%{?sle_version} < 120300
%doc README.md LICENSE
%else
%doc README.md
%license LICENSE
%endif

%dir %attr(0755, root, salt) %{fdir}
%dir %attr(0755, root, salt) %{fdir}/states
%dir %attr(0755, root, salt) %{fdir}/metadata

%attr(0755, root, salt) %{fdir}/states/%{fname}
%attr(0755, root, salt) %{fdir}/states/%{fname}/%{ftemplates}
%attr(0755, root, salt) %{fdir}/metadata/%{fname}

%changelog
* Wed Jul  7 2021 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.6.6
  * fix sap_host_exporter to run on both HA nodes
* Thu Jun 17 2021 Eike Waldt <waldt@b1-systems.de>
- Version bump 0.6.5
  * add native fencing for microsoft-azure
* Fri May 21 2021 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.6.4
  * Set default empty dictionary for virtual_addresses and ensure
    a dictionary is obtained if the value is None (hack for SUMA)
    (bsc#1185627)
* Wed May 19 2021 Peter Varkoly <varkoly@suse.com>
- Version bump 0.6.3
  * Fix issue: azure-lb resource for ASCS/ERS is not added
    in the corresponding Resource Group
    (bsc#1186236)
* Tue Feb 23 2021 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.6.2
  * Set the virtual ip addresses as permanent, except for HA
  scenarios, to have them even after a reboot of the machine
  (bsc#1185093)
* Fri Feb 19 2021 Xabier Arbulu <xarbulu@suse.com>
- Add some mandatory values in the DB and PAS templates for S4HANA
  to avoid executions without them in the extra_parameters field
* Mon Feb 15 2021 Xabier Arbulu <xarbulu@suse.com>
- Give the option to mount /sapmnt folder locally without using
  a NFS share
- Make /sapmnt path configurable using `sapmnt_path` pillar variable
* Wed Feb 10 2021 Xabier Arbulu <xarbulu@suse.com>
- Update PAS and AAS templates to use HANA sid and instance number
  to create the configuration file
* Thu Jan 28 2021 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.6.1
  * Fix error about missing instance installation requisite when monitoring is enabled
  (bsc#1181541)
* Tue Jan 19 2021 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.6.0
  * Change salt-formulas-configuration requirement in SLE12 codestream
  to a recommendation
  (bsc#1177860)
* Thu Dec  3 2020 Simranpal Singh <simranpal.singh@suse.com>
- Add requisites of netweaver installation to subsequent salt states
* Wed Dec  2 2020 Simranpal Singh <simranpal.singh@suse.com>
- Start the saptune systemd service
* Thu Nov 19 2020 Xabier Arbulu <xarbulu@suse.com>
- Fix additional_dvds variable usage when salt uses python 2. The
  variable is filtered by 'tojson' option to avoid 'u' prefix in
  lists
* Mon Oct 19 2020 Xabier Arbulu <xarbulu@suse.com>
- Set the native fence mechanism usage for CSP as optional
- Add instance name suffix to socat resources
- Remove meta resource-stickness to the ERS resources group
* Thu Oct 15 2020 Xabier Arbulu <xarbulu@suse.com>
- Update the db installation template to use correctly the schema
  names for S/4HANA
* Wed Oct 14 2020 Simranpal Singh <simranpal.singh@suse.com>
- Update the default 'nw_extract_dir' SWPM media extraction location
* Wed Oct  7 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.5.2
  * Create SUMA form based on latest pillar and formula data
  (jsc#SLE-4047)
* Thu Sep 24 2020 Xabier Arbulu <xarbulu@suse.com>
- Implement the differences between ENSA1 and ENSA2 versions
- Add the keepalive configuration changes
* Thu Aug 20 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.5.1
  * Add pillar.example to package
  (bsc#1174994, jsc#SLE-4047)
* Thu May 28 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.5.0
  * Add support to extract nw media archives
  * This change brings non backward compatible changes. Remove default swpm installer extract directory and
    add nw_extract_dir variable to store all extracted NW media
* Mon May 18 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.4.4
  * Use gcp-vpc-move-route properly using independent route names
  for ASCS and ERS instances
  (jsc#ECO-1965, jsc#SLE-4047)
* Fri May 15 2020 Stefano Torresi <stefano.torresi@suse.com>
- Version 0.4.3
  * Update monitoring settings
* Tue May 12 2020 Xabier Arbulu Insausti <xarbulu@localhost>
- Version 0.4.2
  * Fix the shared disk usage in non HA environments
* Wed Apr 22 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.4.1
  * Make it optional to install netweaver required packages
* Tue Apr 21 2020 Stefano Torresi <stefano.torresi@suse.com>
- Version 0.4.0
  * Add Pacemaker resources for the sap_host_exporter
* Fri Apr 17 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.3.0
  * Adapt the cluster template to use the proper gcp agents
  (bsc#1161898, bsc#1160933)
* Tue Apr 14 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.2.11
  * Update anyting socat resource by azure-lb as recommended in
  the updated best practices guide
* Fri Mar 27 2020 Simranpal Singh <simranpal.singh@suse.com>
- Version 0.2.10
  * Add support for extracting installer sar file
  * Update installation logic to use installer from extracted installation media
* Fri Mar 20 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.2.9
  * Install pydbapi package to connect to the HANA database
* Tue Mar 17 2020 Dario Maiocchi <dmaiocchi@suse.com>
- Version 0.2.8
  * Fix non-unique ID name error for monitoring.sls state
  * Manage properly multiple exporters execution in the same host
    update spec
* Mon Mar 16 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.2.7
  * Add option to set custom parameters in the installation
    configuration files
  * Make the installation retry times customizable
* Tue Mar 10 2020 Dario Maiocchi <dmaiocchi@suse.com>
- Version 0.2.6
  * Add option to activate the sap_host_exporter on the nodes
* Mon Mar  9 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.2.5
  * Fix "stonith-action" parameter usage in the HA cluster
    template for aws
    (jsc#SLE-4143, boo#1137989)
* Fri Feb 21 2020 Xabier Arbulu <xarbulu@suse.com>
- Version 0.2.4
  * Adapt the formula and HA template to work with aws RA
  * Make nfs share option configurable
  (bsc#1165156, jsc#SLE-4143, boo#1137989)
* Tue Jan 28 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.2.3
  * Adapt HA template to support gcp
* Mon Jan 27 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.2.2
  * Add the virtual_host_mask parameter to NW installation
* Fri Jan 24 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.2.1
  * Make the product_id parameter variable to provide the option
    to install other SAP products than NW750
* Thu Jan 23 2020 Dario Maiocchi <dmaiocchi@suse.com>
- Version bump 0.2.0
  * Add saptune module to apply a specific solutionn
* Mon Jan 20 2020 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.1.9
  * Improve the shared disk creation to avoid issues mounting and
    formatting the partitions (and later on with SAP instances)
* Thu Dec 19 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.1.8
  * Update cloud provider data usage
* Mon Dec  9 2019 Simranpal Singh <simranpal.singh@suse.com>
- Version bump 0.1.7
  * Provide the option to set individual sapadm and <sid>adm passwords
    and set master password as default for all NW instances
* Thu Dec  5 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.1.6
  * Adapt the formula to work with azure standards
* Thu Nov 28 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.1.5
  * Fix sapcontrol commands usage adding a sleep after them to give
    sapcontrol time to perform the actions
  * Fix list of string management converting to json:
    https://docs.saltstack.com/en/latest/topics/releases/2019.2.0.html#non-backward-compatible-change-to-yaml-renderer
* Thu Nov 14 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.1.4
  * Add option to create the sidadm user and update NW folders
    to that user
* Mon Nov 11 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.1.3
  * Fix issue with file permissions during package installation in
    /usr/share/salt-formulas (0755, root, salt)
    (boo#1142306)
* Wed Nov  6 2019 Simranpal Singh <simranpal.singh@suse.com>
- Version bump 0.1.2
  * Add check if sap profile directory exists before NW components
    install
  * Change the retry/interval values for profile directory check
* Thu Oct 31 2019 Xabier Arbulu <xarbulu@suse.com>
- Version bump 0.1.1
  * Remove the swpm_media parameter. Now the installation files
    must already exist in the system
* Wed Oct 16 2019 Xabier Arbulu <xarbulu@suse.com>
- Create first package version 0.1.0
  * Setup the required infrastructure to install NW
  * Install ASCS, ERS, DB, PAS and AAS instances
  * Perform all of the operations to enable HA between ASCS and ERS
